@@ -1,9 +1,10 @@
 from .application import App
+from .exceptions import HTTPException
 from .request import Request
 from .response import Response
 from .routing import Router
 from .websockets import WebSocket
 
-__version__ = "0.1.4"
+__version__ = "0.1.7"
 
-__all__ = ["App", "Request", "Response", "WebSocket", "Router"]
+__all__ = ["App", "Request", "Response", "WebSocket", "Router", "HTTPException"]
