@@ -4,7 +4,6 @@ HTTPS Redirect Middleware for Xyra Framework
 This middleware redirects HTTP requests to HTTPS.
 """
 
-from collections.abc import Callable
 
 from ..request import Request
 from ..response import Response
@@ -22,10 +21,12 @@ class HTTPSRedirectMiddleware:
         """
         self.redirect_status_code = redirect_status_code
 
-    def __call__(self, req: Request, res: Response, next_handler: Callable):
+    def __call__(self, req: Request, res: Response):
         """Redirect HTTP requests to HTTPS."""
         # Check if request is HTTP
-        if req.headers.get("X-Forwarded-Proto", "").lower() == "http" or not req.url.startswith("https://"):
+        if req.headers.get(
+            "X-Forwarded-Proto", ""
+        ).lower() == "http" or not req.url.startswith("https://"):
             # Build HTTPS URL
             https_url = req.url.replace("http://", "https://", 1)
 
@@ -33,12 +34,14 @@ class HTTPSRedirectMiddleware:
             res.status(self.redirect_status_code)
             res.header("Location", https_url)
             res.send("")
+            res._ended = True
             return
 
-        # Continue to next handler
-        next_handler()
+        # Continue to next middleware
 
 
-def https_redirect_middleware(redirect_status_code: int = 301) -> HTTPSRedirectMiddleware:
+def https_redirect_middleware(
+    redirect_status_code: int = 301,
+) -> HTTPSRedirectMiddleware:
     """Create an HTTPS redirect middleware instance."""
     return HTTPSRedirectMiddleware(redirect_status_code)
